import type { GomokuDirectionType } from '../constant';
import type { IDirCounter, IGomokuBoard, IGomokuPiece } from '../types/misc';
import type { IGomokuMoverContext } from '../types/mover-context';
declare type IGomokuDirections = number[];
declare type IIdxMap = Array<Readonly<[r: number, c: number]>>;
export interface IGomokuMoverContextProps {
    MAX_ROW: number;
    MAX_COL: number;
    MAX_ADJACENT: number;
    MAX_DISTANCE_OF_NEIGHBOR: number;
}
export declare class GomokuMoverContext implements IGomokuMoverContext {
    readonly MAX_ROW: number;
    readonly MAX_COL: number;
    readonly MAX_ADJACENT: number;
    readonly MAX_DISTANCE_OF_NEIGHBOR: number;
    readonly TOTAL_PLAYER: number;
    readonly TOTAL_POS: number;
    readonly MIDDLE_POS: number;
    readonly board: Readonly<IGomokuBoard>;
    protected readonly _idxMap: Readonly<IIdxMap>;
    protected readonly _gomokuDirections: Readonly<IGomokuDirections>;
    protected readonly _maxMovableMap: number[][];
    protected readonly _dirStartPosMap: number[][];
    protected readonly _dirStartPosSet: number[][];
    protected readonly _dirNeighborSet: number[][];
    protected readonly _neighborPlacedCount: number[];
    protected readonly _rightHalfDirCountMap: IDirCounter[][][];
    protected _placedCount: number;
    constructor(props: IGomokuMoverContextProps);
    get placedCount(): number;
    init(pieces: ReadonlyArray<IGomokuPiece>): void;
    forward(posId: number, playerId: number): void;
    revert(posId: number): void;
    idx(r: number, c: number): number;
    revIdx(posId: number): Readonly<[r: number, c: number]>;
    isValidPos(r: number, c: number): boolean;
    isValidIdx(posId: number): boolean;
    safeMove(posId: number, dirType: GomokuDirectionType, step: number): number;
    safeMoveOneStep(posId: number, dirType: GomokuDirectionType): number;
    fastMove(posId: number, dirType: GomokuDirectionType, step: number): number;
    fastMoveOneStep(posId: number, dirType: GomokuDirectionType): number;
    maxMovableSteps(posId: number, dirType: GomokuDirectionType): number;
    accessibleNeighbors(posId: number): Iterable<number>;
    hasPlacedNeighbors(posId: number): boolean;
    couldReachFinalInDirection(playerId: number, posId: number, dirType: GomokuDirectionType): boolean;
    getStartPosId(posId: number, dirType: GomokuDirectionType): number;
    getStartPosSet(dirType: GomokuDirectionType): Iterable<number>;
    getDirCounters(startPosId: number, dirType: GomokuDirectionType): ReadonlyArray<IDirCounter>;
    traverseAllDirections(handle: (dirType: GomokuDirectionType) => (posId: number) => void): void;
    protected _updateHalfDirCounter(playerId: number, posId: number, dirType: GomokuDirectionType): void;
}
export {};
